@@ -1,6 +1,6 @@
 DATA = {
   "Examples": [], 
-  "dist": "python-qprogedit-4.0.5_2-py_0", 
+  "dist": "python-qprogedit-4.0.6-py_0", 
   "python-scripts": [], 
   "site-packages": [
     "QProgEdit/__init__.py", 
@@ -30,12 +30,12 @@ DATA = {
     "QProgEdit/ui/prefsWidget.ui", 
     "QProgEdit/validate/__init__.py", 
     "QProgEdit/validate/_python.py", 
-    "python_qprogedit-4.0.5-py2.7.egg-info/PKG-INFO", 
-    "python_qprogedit-4.0.5-py2.7.egg-info/SOURCES.txt", 
-    "python_qprogedit-4.0.5-py2.7.egg-info/dependency_links.txt", 
-    "python_qprogedit-4.0.5-py2.7.egg-info/not-zip-safe", 
-    "python_qprogedit-4.0.5-py2.7.egg-info/requires.txt", 
-    "python_qprogedit-4.0.5-py2.7.egg-info/top_level.txt"
+    "python_qprogedit-4.0.6-py2.7.egg-info/PKG-INFO", 
+    "python_qprogedit-4.0.6-py2.7.egg-info/SOURCES.txt", 
+    "python_qprogedit-4.0.6-py2.7.egg-info/dependency_links.txt", 
+    "python_qprogedit-4.0.6-py2.7.egg-info/not-zip-safe", 
+    "python_qprogedit-4.0.6-py2.7.egg-info/requires.txt", 
+    "python_qprogedit-4.0.6-py2.7.egg-info/top_level.txt"
   ]
 }
 ## END DATA
